#
# spec file for package python-django_compressor
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-django_compressor
Version:        1.5
Release:        6.5
Summary:        Compresses Linked and Inline JavaScript or CSS Into Single Cached Files
License:        MIT and BSD-3-Clause and Apache-2.0
Group:          Development/Languages/Python
Url:            http://django_compressor.readthedocs.org/
Source:         http://pypi.python.org/packages/source/d/django_compressor/django_compressor-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python-django
Requires:       python-django-appconf
%if 0%{?suse_version}
Suggests:       python-beautifulsoup
Suggests:       python-html5lib
Suggests:       python-lxml
Suggests:       python-slimit
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Django Compressor combines and compresses linked and inline Javascript or CSS
in a Django templates into cacheable static files by using the "compress"
template tag.

%prep
%setup -q -n django_compressor-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README.rst
%{python_sitelib}/*

%changelog
* Sat Jul 25 2015 seife+obs@b1-systems.com
- fix non-suse build by conditionalizing "Suggests" tags
* Thu Jul 23 2015 dmueller@suse.com
- update to 1.5:
  - Fix compress command and run automated tests for Django 1.8
  - Fix Django 1.8 warnings
  - Handle TypeError from import_module
  - Fix reading UTF-8 files which have BOM
  - Fix incompatibility with Windows (shell_quote is not supported)
  - Run automated tests on Django 1.7
  - Ignore non-existent {{ block.super }} in offline compression instead of raising AttributeError
  - Support for clean-css
  - Fix link markup
  - Add support for COMPRESS_CSS_HASHING_METHOD = None
  - Remove compatibility with old 'staticfiles' app
  - In compress command, use get_template() instead of opening template files manually, fixing compatibility issues
  - Fix FilterBase so that does not override self.type for subclasses if filter_type is not specified at init
  - Remove unnecessary filename and existence checks in CssAbsoluteFilter
* Thu Jun 26 2014 dmueller@suse.com
- update to 1.4:
  - Added Python 3 compatibility.
  - Added compatibility with Django 1.6.x.
  - Fixed compatibility with html5lib 1.0.
  - Added offline compression for Jinja2 with Jingo and Coffin integration.
  - Improved support for template inheritance in offline compression.
  - Made offline compression avoid compressing the same block multiple times.
  - Added a ``testenv`` target in the Makefile to make it easier to set up the
  test environment.
  - Allowed data-uri filter to handle external/protocol-relative references.
  - Made ``CssCompressor`` class easier to extend.
  - Added support for explictly stating the block being ended.
  - Added rcssmin and updated rjsmin.
  - Removed implicit requirement on BeautifulSoup.
  - Made GzipCompressorFileStorage set access and modified times to the same time
  as the corresponding base file.
  - Defaulted to using django's simplejson, if present.
  - Fixed CompilerFilter to always output Unicode strings.
  - Fixed windows line endings in offline compression.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon May 13 2013 dmueller@suse.com
- update to 1.3:
- *Backward incompatible changes*
  - Dropped support for Python 2.5. Removed ``any`` and ``walk`` compatibility
    functions in ``compressor.utils``.
  - Removed compatibility with Django 1.2 for default values of some settings:
  - :attr:`~COMPRESS_ROOT` no longer uses ``MEDIA_ROOT`` if ``STATIC_ROOT`` is
    not defined. It expects ``STATIC_ROOT`` to be defined instead.
  - :attr:`~COMPRESS_URL` no longer uses ``MEDIA_URL`` if ``STATIC_URL`` is
    not defined. It expects ``STATIC_URL`` to be defined instead.
  - :attr:`~COMPRESS_CACHE_BACKEND` no longer uses ``CACHE_BACKEND`` and simply
    defaults to ``default``.
- Added precompiler class support. This enables you to write custom precompilers
  with Python logic in them instead of just relying on executables.
- Made CssAbsoluteFilter smarter: it now handles URLs with hash fragments or
  querystring correctly. In addition, it now leaves alone fragment-only URLs.
- Removed a ``fsync()`` call in ``CompilerFilter`` to improve performance.
  We already called ``self.infile.flush()`` so that call was not necessary.
- Added an extension to provide django-sekizai support.
  See :ref:`django-sekizai Support <django-sekizai_support>` for more
  information.
- Fixed a ``DeprecationWarning`` regarding the use of ``django.utils.hashcompat``
- Updated bundled ``rjsmin.py`` to fix some JavaScript compression errors.
* Wed Nov 28 2012 saschpe@suse.de
- Add suggestions for useful additions:
  + python-beautifulsoup
  + python-html5lib
  + python-lxml
  + python-slimit
* Mon Nov 26 2012 cfarrell@suse.com
- license update: MIT and BSD-3-Clause and Apache-2.0
* Tue Nov 13 2012 jfunk@funktronics.ca
- Update to 1.2:
  * Added compatibility with Django 1.4 and dropped support for Django 1.2.X.
  * Added contributing docs. Be sure to check them out and start contributing!
  * Moved CI to Travis: http://travis-ci.org/jezdez/django_compressor
  * Introduced a new compressed context dictionary that is passed to the
    templates that are responsible for rendering the compressed snippets.
    This is a backwards-incompatible change if you've overridden any of the included templates:
    compressor/css_file.html
    compressor/css_inline.html
    compressor/js_file.html
    compressor/js_inline.html
    The variables passed to those templates have been namespaced in a
    dictionary, so it's easy to fix your own templates.
    For example, the old compressor/js_file.html:
    <script type="text/javascript" src="{{ url }}"></script>
    The new compressor/js_file.html:
    <script type="text/javascript" src="{{ compressed.url }}"></script>
  * Removed old templates named compressor/css.html and compressor/js.html
    that were originally left for backwards compatibility. If you've
    overridden them, just rename them to compressor/css_file.html or
    compressor/js_file.html and make sure you've accounted for the backwards
    incompatible change of the template context mentioned above.
  * Reverted an unfortunate change to the YUI filter that prepended
    'java -jar' to the binary name, which doesn't alway work, e.g. if the YUI
    compressor is shipped as a script like /usr/bin/yui-compressor.
  * Changed the sender parameter of the post_compress() signal to be either
    compressor.css.CssCompressor or compressor.js.JsCompressor for easier
    customization.
  * Correctly handle offline compressing files that are found in {%% if %%}
    template blocks.
  * Renamed the second option for the COMPRESS_CSS_HASHING_METHOD setting from
    'hash' to 'content' to better describe what it does. The old name is also
    supported, as well as the default being 'mtime'.
  * Fixed CssAbsoluteFilter, src attributes in includes now get transformed.
  * Added a new hook to allow developers to completely bypass offline
    compression in CompressorNode subclasses: is_offline_compression_enabled.
  * Dropped versiontools from required dependencies again.
* Wed Feb  1 2012 saschpe@suse.de
- Spec file cleanup:
  * Simplified macro usage
  * Removed outdated %%clean section
  * Buildrequire python-distribute instead of setuptools
* Fri Jan 20 2012 jfunk@funktronics.ca
- Add missing requirement for django-appconf
* Thu Jan 12 2012 jfunk@funktronics.ca
- Update to 1.1.2:
  * Fixed an installation issue related to versiontools
* Sat Nov 26 2011 jfunk@funktronics.ca
- Update to 1.1.1:
  - Fixed a stupid ImportError bug introduced in 1.1
  - Fixed Jinja2 docs of since JINJA2_EXTENSIONS expects a class, not a module
  - Fixed a Windows bug with regard to file resolving with staticfiles finders
  - Stopped a potential memory leak when memoizing the rendered output
  - Fixed the integration between staticfiles (e.g. in Django <= 1.3.1) and
    compressor which prevents the collectstatic management command to work
  - Warning - Make sure to remove the path method of your custom remote
    storage class!
- 1.1:
  - Made offline compression completely independent from cache (by writing a
    manifest.json file)
  - You can now easily run the compress management command locally and
    transfer the COMPRESS_ROOT dir to your server
  - Updated installation instructions to properly mention all dependencies,
    even those internally used
  - Fixed a bug introduced in 1.0 which would prevent the proper deactivation
    of the compression in production
  - Added a Jinja2 contrib extension
  - Made sure the rel attribute of link tags can be mixed case
  - Avoid overwriting context variables needed for compressor to work
  - Stopped the compress management command to require model validation
  - Added missing imports and fixed a few PEP 8 issues
- 1.0.1:
  - Fixed regression in compressor.utils.staticfiles compatibility module
- 1.0:
  - BACKWARDS-INCOMPATIBLE Stopped swallowing exceptions raised by rendering
    the template tag in production (DEBUG = False). This has the potential to
    breaking lots of apps but on the other hand will help find bugs
  - BACKWARDS-INCOMPATIBLE The default function to create the cache key
    stopped containing the server hostname. Instead the cache key now only has
    the form 'django_compressor.<KEY>'
  - To revert to the previous way simply set the COMPRESS_CACHE_KEY_FUNCTION
    to 'compressor.cache.socket_cachekey'
  - BACKWARDS-INCOMPATIBLE Renamed ambigously named COMPRESS_DATA_URI_MAX_SIZE
    setting to COMPRESS_DATA_URI_MAX_SIZE. It’s the maximum size the
    compressor.filters.datauri.DataUriFilter filter will embed files as data:
    URIs
  - Added COMPRESS_CSS_HASHING_METHOD setting with the options 'mtime'
    (default) and 'hash' for the CssAbsoluteFilter filter. The latter uses the
    content of the file to calculate the cache-busting hash
  - Added support for {{ block.super }} to compress management command
  - Dropped Django 1.1.X support
  - Fixed compiler filters on Windows
  - Handle new-style cached template loaders in the compress management
    command
  - Documented included filters
  - Added Slim It filter
  - Added new CallbackOutputFilter to ease the implementation of Python-based
    callback filters that only need to pass the content to a callable
  - Make use of django-appconf for settings handling and versiontools for
    versions
  - Uses the current context when rendering the render templates
  - Added post_compress signal
* Wed Jul 27 2011 jfunk@funktronics.ca
- Initial release
